@@ -1,6 +1,6 @@
 /* Copyright (C) 2002, 2003 Mads Martin Joergensen <mmj at mmj.dk>
  *
- * $Id: init_sockfd.c,v 1.12 2005/02/08 18:13:14 mmj Exp $
+ * $Id: init_sockfd.c,v 1.14 2005/02/15 12:49:16 mmj Exp $
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to
@@ -34,7 +34,7 @@
 
 void init_sockfd(int *sockfd, const char *relayhost, unsigned short port)
 {
-	int len;
+	int len, on;
 	struct sockaddr_in addr;
 
 	if (getenv("MLMMJ_TESTING")) {
@@ -56,4 +56,9 @@ void init_sockfd(int *sockfd, const char *relayhost, unsigned short port)
 				    "exiting ... ", relayhost);
 		exit(EXIT_FAILURE);
 	}
+
+	on = 1;
+	if(setsockopt(*sockfd, SOL_SOCKET, SO_KEEPALIVE, (void *)&on,
+				sizeof(on)) < 0)
+		log_error(LOG_ARGS, "Could not set SO_KEEPALIVE");
 }
