@@ -1,6 +1,6 @@
 /* Copyright (C) 2002, 2003 Mads Martin Joergensen <mmj at mmj.dk>
  *
- * $Id: mlmmj-sub.c,v 1.42 2005/06/20 12:40:39 mmj Exp $
+ * $Id: mlmmj-sub.c,v 1.44 2005/10/09 14:17:52 mmj Exp $
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to
@@ -38,6 +38,7 @@
 #include "mylocking.h"
 #include "wrappers.h"
 #include "getlistaddr.h"
+#include "getlistdelim.h"
 #include "strgen.h"
 #include "subscriberfuncs.h"
 #include "log_error.h"
@@ -47,15 +48,15 @@
 #include "memory.h"
 
 void confirm_sub(const char *listdir, const char *listaddr,
-		const char *subaddr, const char *mlmmjsend,
-		enum subtype typesub)
+		const char *listdelim, const char *subaddr,
+		const char *mlmmjsend, enum subtype typesub)
 {
 	char *queuefilename, *fromaddr, *listname, *listfqdn, *listtext;
 
 	listname = genlistname(listaddr);
 	listfqdn = genlistfqdn(listaddr);
 
-	fromaddr = concatstr(3, listname, "+bounces-help@", listfqdn);
+	fromaddr = concatstr(4, listname, listdelim, "bounces-help@", listfqdn);
 
 	myfree(listname);
 	myfree(listfqdn);
@@ -88,8 +89,8 @@ void confirm_sub(const char *listdir, const char *listaddr,
 }
 
 void notify_sub(const char *listdir, const char *listaddr,
-		const char *subaddr, const char *mlmmjsend,
-		enum subtype typesub)
+		const char *listdelim, const char *subaddr,
+		const char *mlmmjsend, enum subtype typesub)
 {
 	char *maildata[2] = { "newsub", NULL };
 	char *listfqdn, *listname, *fromaddr, *tostr;
@@ -100,8 +101,8 @@ void notify_sub(const char *listdir, const char *listaddr,
 
 	maildata[1] = mystrdup(subaddr);
 	
-	fromaddr = concatstr(3, listname, "+bounces-help@", listfqdn);
-	tostr = concatstr(3, listname, "+owner@", listfqdn);
+	fromaddr = concatstr(4, listname, listdelim, "bounces-help@", listfqdn);
+	tostr = concatstr(4, listname, listdelim, "owner@", listfqdn);
 	
 	myfree(listname);
 	myfree(listfqdn);
@@ -135,8 +136,8 @@ void notify_sub(const char *listdir, const char *listaddr,
 }
 
 void generate_subconfirm(const char *listdir, const char *listaddr,
-			 const char *subaddr, const char *mlmmjsend,
-			 enum subtype typesub)
+			 const char *listdelim, const char *subaddr,
+			 const char *mlmmjsend, enum subtype typesub)
 {
 	int subconffd;
 	char *confirmaddr, *listname, *listfqdn, *confirmfilename = NULL;
@@ -177,26 +178,27 @@ void generate_subconfirm(const char *listdir, const char *listaddr,
 
 	close(subconffd);
 
-	fromaddr = concatstr(5, listname, "+bounces-confsub-", randomstr,
-				"@", listfqdn);
+	fromaddr = concatstr(6, listname, listdelim, "bounces-confsub-",
+				randomstr, "@", listfqdn);
 	
 	switch(typesub) {
 		default:
 		case SUB_NORMAL:
 			listtext = mystrdup("sub-confirm");
-			tmpstr = mystrdup("+confsub-");
+			tmpstr = mystrdup("confsub-");
 			break;
 		case SUB_DIGEST:
 			listtext = mystrdup("sub-confirm-digest");
-			tmpstr = mystrdup("+confsub-digest-");
+			tmpstr = mystrdup("confsub-digest-");
 			break;
 		case SUB_NOMAIL:
 			listtext = mystrdup("sub-confirm-nomail");
-			tmpstr = mystrdup("+confsub-nomail-");
+			tmpstr = mystrdup("confsub-nomail-");
 			break;
 	}
 
-	confirmaddr = concatstr(5, listname, tmpstr, randomstr, "@", listfqdn);
+	confirmaddr = concatstr(6, listname, listdelim, tmpstr, randomstr, "@",
+				listfqdn);
 
 	myfree(randomstr);
 	myfree(tmpstr);
@@ -245,12 +247,14 @@ void generate_subscribed(const char *listdir, const char *subaddr,
 		const char *mlmmjsend)
 {
 	char *queuefilename, *fromaddr, *listname, *listfqdn, *listaddr;
+	char *listdelim = getlistdelim(listdir);
 
 	listaddr = getlistaddr(listdir);
 	listname = genlistname(listaddr);
 	listfqdn = genlistfqdn(listaddr);
 
-	fromaddr = concatstr(3, listname, "+bounces-help@", listfqdn);
+	fromaddr = concatstr(4, listname, listdelim, "bounces-help@", listfqdn);
+	myfree(listdelim);
 
 	queuefilename = prepstdreply(listdir, "sub-subscribed", "$helpaddr$",
 				     subaddr, NULL, 0, NULL);
@@ -272,14 +276,13 @@ void generate_subscribed(const char *listdir, const char *subaddr,
 
 int main(int argc, char **argv)
 {
-	char *listaddr, *listdir = NULL, *address = NULL, *subfilename = NULL;
-	char *mlmmjsend, *bindir, chstr[2], *subdir, *subddirname = NULL;
-	char *sublockname;
+	char *listaddr, *listdelim, *listdir = NULL, *address = NULL;
+	char *subfilename = NULL, *mlmmjsend, *bindir, chstr[2], *subdir;
+	char *subddirname = NULL, *sublockname;
 	int subconfirm = 0, confirmsub = 0, opt, subfilefd, lock, notifysub;
 	int changeuid = 1, status, digest = 0, nomail = 0;
-	int groupwritable = 0, sublock, sublockfd, nogensubscribed = 0;
+	int groupwritable = 0, sublock, sublockfd, nogensubscribed = 0, subbed;
 	size_t len;
-	off_t suboff;
 	struct stat st;
 	pid_t pid, childpid;
 	uid_t uid;
@@ -364,7 +367,20 @@ int main(int argc, char **argv)
 		exit(EXIT_SUCCESS);  /* XXX is this success? */
 	}
 
-	subddirname = concatstr(2, listdir, "/subscribers.d");
+	switch(typesub) {
+		default:
+		case SUB_NORMAL:
+			subdir = "/subscribers.d/";
+			break;
+		case SUB_DIGEST:
+			subdir = "/digesters.d/";
+			break;
+		case SUB_NOMAIL:
+			subdir = "/nomailsubs.d/";
+			break;
+	}
+
+	subddirname = concatstr(2, listdir, subdir);
 	if (stat(subddirname, &st) == 0) {
 		if(st.st_mode & S_IWGRP) {
 			groupwritable = S_IRGRP|S_IWGRP;
@@ -389,19 +405,6 @@ int main(int argc, char **argv)
 	chstr[0] = address[0];
 	chstr[1] = '\0';
 	
-	switch(typesub) {
-		default:
-		case SUB_NORMAL:
-			subdir = "/subscribers.d/";
-			break;
-		case SUB_DIGEST:
-			subdir = "/digesters.d/";
-			break;
-		case SUB_NOMAIL:
-			subdir = "/nomailsubs.d/";
-			break;
-	}
-		
 	subfilename = concatstr(3, listdir, subdir, chstr);
 
 	sublockname = concatstr(5, listdir, subdir, ".", chstr, ".lock");
@@ -438,15 +441,16 @@ int main(int argc, char **argv)
 		myfree(sublockname);
 		exit(EXIT_FAILURE);
 	}
-	suboff = find_subscriber(subfilefd, address);
-	if(suboff == -1) {
+	subbed = is_subbed_in(subddirname, address);
+	listdelim = getlistdelim(listdir);
+	if(subbed) {
 		if(subconfirm) {
 			close(subfilefd);
 			close(sublockfd);
 			unlink(sublockname);
 			myfree(sublockname);
-			generate_subconfirm(listdir, listaddr, address,
-					    mlmmjsend, typesub);
+			generate_subconfirm(listdir, listaddr, listdelim,
+					    address, mlmmjsend, typesub);
 		} else {
 			lseek(subfilefd, 0L, SEEK_END);
 			len = strlen(address);
@@ -479,8 +483,8 @@ int main(int argc, char **argv)
 
 		if(childpid < 0) {
 			log_error(LOG_ARGS, "Could not fork");
-			confirm_sub(listdir, listaddr, address, mlmmjsend,
-					typesub);
+			confirm_sub(listdir, listaddr, listdelim, address,
+					mlmmjsend, typesub);
 		}
 		
 		if(childpid > 0) {
@@ -491,17 +495,19 @@ int main(int argc, char **argv)
 
 		/* child confirms subscription */
 		if(childpid == 0)
-			confirm_sub(listdir, listaddr, address, mlmmjsend,
-					typesub);
+			confirm_sub(listdir, listaddr, listdelim, address,
+					mlmmjsend, typesub);
 	}
 
 	notifysub = statctrl(listdir, "notifysub");
 
 	/* Notify list owner about subscription */
 	if (notifysub)
-		notify_sub(listdir, listaddr, address, mlmmjsend, typesub);
+		notify_sub(listdir, listaddr, listdelim, address, mlmmjsend,
+				typesub);
 
 	myfree(listaddr);
+	myfree(listdelim);
 
 	return EXIT_SUCCESS;
 }
